<?php

namespace Restaurant\Discount\Policies;

use Litepie\User\Contracts\UserPolicy;
use Restaurant\Discount\Models\Discount;

class DiscountPolicy
{

    /**
     * Determine if the given user can view the discount.
     *
     * @param UserPolicy $user
     * @param Discount $discount
     *
     * @return bool
     */
    public function view(UserPolicy $user, Discount $discount)
    {
        if ($user->canDo('discount.discount.view') && $user->isAdmin()) {
            return true;
        }

        return $discount->user_id == user_id() && $discount->user_type == user_type();
    }

    /**
     * Determine if the given user can create a discount.
     *
     * @param UserPolicy $user
     * @param Discount $discount
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('discount.discount.create');
    }

    /**
     * Determine if the given user can update the given discount.
     *
     * @param UserPolicy $user
     * @param Discount $discount
     *
     * @return bool
     */
    public function update(UserPolicy $user, Discount $discount)
    {
        if ($user->canDo('discount.discount.edit') && $user->isAdmin()) {
            return true;
        }

        return $discount->user_id == user_id() && $discount->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given discount.
     *
     * @param UserPolicy $user
     * @param Discount $discount
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Discount $discount)
    {
        return $discount->user_id == user_id() && $discount->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given discount.
     *
     * @param UserPolicy $user
     * @param Discount $discount
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Discount $discount)
    {
        if ($user->canDo('discount.discount.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given discount.
     *
     * @param UserPolicy $user
     * @param Discount $discount
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Discount $discount)
    {
        if ($user->canDo('discount.discount.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
